summaryrefslogtreecommitdiff
path: root/glob/fnmatch.h
diff options
context:
space:
mode:
authorPaul Smith <psmith@gnu.org>1999-07-22 04:20:14 +0000
committerPaul Smith <psmith@gnu.org>1999-07-22 04:20:14 +0000
commitec50fe2a2baf518181896a0cc5f376eb4d47ff0a (patch)
tree24a371fa169122d485250f3ed33f79b733de6f95 /glob/fnmatch.h
parentc69d4c95bf2027252e13e4dec3fb2dcfd10fc4e7 (diff)
downloadgunmake-ec50fe2a2baf518181896a0cc5f376eb4d47ff0a.tar.gz
* Installed new versions of GLIBC glob library.
* Installed Tim Magill's "graph pruning" performance enhancement. * Update version to 3.77.90 for the release. * Require automake 1.4.
Diffstat (limited to 'glob/fnmatch.h')
-rw-r--r--glob/fnmatch.h14
1 files changed, 8 insertions, 6 deletions
diff --git a/glob/fnmatch.h b/glob/fnmatch.h
index 4d1eb3e..cc3ec37 100644
--- a/glob/fnmatch.h
+++ b/glob/fnmatch.h
@@ -1,4 +1,4 @@
-/* Copyright (C) 1991, 1992, 1993, 1996, 1997 Free Software Foundation, Inc.
+/* Copyright (C) 1991, 92, 93, 96, 97, 98, 99 Free Software Foundation, Inc.
This file is part of the GNU C Library.
The GNU C Library is free software; you can redistribute it and/or
@@ -24,8 +24,10 @@ extern "C" {
#endif
#if defined __cplusplus || (defined __STDC__ && __STDC__) || defined WINDOWS32
-# undef __P
-# define __P(protos) protos
+# if !defined __GLIBC__ || !defined __P
+# undef __P
+# define __P(protos) protos
+# endif
#else /* Not C++ or ANSI C. */
# undef __P
# define __P(protos) ()
@@ -66,13 +68,13 @@ extern "C" {
`fnmatch'. Since this is not the case here it will never be
returned but the conformance test suites still require the symbol
to be defined. */
-#if (_XOPEN_SOURCE - 0) == 500
+#ifdef _XOPEN_SOURCE
# define FNM_NOSYS (-1)
#endif
/* Match STRING against the filename pattern PATTERN,
returning zero if it matches, FNM_NOMATCH if not. */
-extern int fnmatch __P ((__const char *__pattern, __const char *__string,
+extern int fnmatch __P ((__const char *__pattern, __const char *__name,
int __flags));
#ifdef __cplusplus
@@ -66,13 +68,13 @@ extern "C" {
# define FNM_NOSYS (-1)
#endif
-/* Match STRING against the filename pattern PATTERN,
+/* Match NAME against the filename pattern PATTERN,
returning zero if it matches, FNM_NOMATCH if not. */